@@ -1,38 +1,30 @@
 from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Permission
 from django.contrib.auth.backends import ModelBackend, AllowAllUsersModelBackend, RemoteUserBackend, AllowAllUsersRemoteUserBackend
+from django.contrib.sites.models import Site
 
-
-class GroupSiteFilterMixin():
+class GroupSiteModelBackendMixin():
 
     def _get_group_permissions(self, user_obj):
         '''
         Adds the SiteID for filtering Groups
         '''
+        current_site = Site.objects.get_current()
         user_groups_field = get_user_model()._meta.get_field('groups')
         user_groups_query = 'group__%s' % user_groups_field.related_query_name()
-        return Permission.objects.filter(**{user_groups_query: user_obj})                   # TODO: Should it return Groups that do not have a Permafrost Role also?
+
+        return Permission.objects.filter(**{user_groups_query: user_obj}).filter(group__permafrost_role__site=current_site)                   # TODO: Should it return Groups that do not have a Permafrost Role also?
 
 
-class PermafrostModelBackend(GroupSiteFilterMixin, ModelBackend):
+class PermafrostModelBackend(GroupSiteModelBackendMixin, ModelBackend):
     '''
     Permafrost ModelBackend that takes into account SiteID when filtering on
     Group permissions via Permafrost Roles.
     '''
     pass
-    # def _get_group_permissions(self, user_obj):
-    #     return super()._get_group_permissions(user_obj).filter(group__permafrost_role__site=current_site)       # filter out groups in permaforstroles within the current site
-        
-        
-    # def get_group_permissions(self, user_obj, obj=None):
-    #     """
-    #     Return a set of permission strings the user `user_obj` has from the
-    #     groups they belong.
-    #     """
-    #     return self._get_permissions(user_obj, obj, 'group')
 
 
-class PermafrostAllowAllUsersModelBackend(GroupSiteFilterMixin, AllowAllUsersModelBackend):
+class PermafrostAllowAllUsersModelBackend(GroupSiteModelBackendMixin, AllowAllUsersModelBackend):
     '''
     Permafrost AllowAllUsersModelBackend that takes into account SiteID when filtering on
     Group permissions via Permafrost Roles.
@@ -40,7 +32,7 @@ class PermafrostAllowAllUsersModelBackend(GroupSiteFilterMixin, AllowAllUsersMod
     pass
 
 
-class PermafrostRemoteUserBackend(GroupSiteFilterMixin, RemoteUserBackend):
+class PermafrostRemoteUserBackend(GroupSiteModelBackendMixin, RemoteUserBackend):
     '''
     Permafrost RemoteUserBackend that takes into account SiteID when filtering on
     Group permissions via Permafrost Roles.
@@ -48,7 +40,7 @@ class PermafrostRemoteUserBackend(GroupSiteFilterMixin, RemoteUserBackend):
     pass
 
 
-class PermafrostAllowAllUsersRemoteUserBackend(GroupSiteFilterMixin, AllowAllUsersRemoteUserBackend):
+class PermafrostAllowAllUsersRemoteUserBackend(GroupSiteModelBackendMixin, AllowAllUsersRemoteUserBackend):
     '''
     Permafrost AllowAllUsersRemoteUserBackend that takes into account SiteID when filtering on
     Group permissions via Permafrost Roles.
